@@ -27,7 +27,7 @@ class BylineList(PersistentJSONable):
     # ----------------------------------------------------------------------------------------------------------------
 
     @classmethod
-    def construct_from_jdict(cls, jdict, default=True):
+    def construct_from_jdict(cls, jdict, skeleton=False):
         if not jdict:
             return None
 
@@ -42,6 +42,8 @@ class BylineList(PersistentJSONable):
         """
         Constructor
         """
+        super().__init__()
+
         self.__byline_list = byline_list
 
     # ----------------------------------------------------------------------------------------------------------------
