@@ -38,7 +38,11 @@ class ClimateSample(Sample):
         # Sample...
         tag = jdict.get('tag')
         rec = LocalizedDatetime.construct_from_jdict(jdict.get('rec'))
-        version = jdict.get('ver', cls.DEFAULT_VERSION)
+
+        try:
+            version = float(jdict.get('ver'))
+        except (TypeError, ValueError):
+            version = cls.DEFAULT_VERSION
 
         val = jdict.get('val')
         exegeses = jdict.get('exg')
